Settings

Configure these in Settings (Ctrl+, / Cmd+,) or in settings.json.

SettingTypeDefaultDescription
aks.aksmcpserver.enabledComponentsstring"az_cli,monitor,fleet,network,compute,detectors,advisor,inspektorgadget,kubectl"Comma-separated list of enabled components (empty means all components enabled). Available: az_cli, monitor, fleet, network, compute, detectors, advisor, inspektorgadget, kubectl, helm, cilium, hubble. Some components require local CLI tools (e.g. helm, cilium, hubble).
aks.aksmcpserver.releaseTagstring"v0.0.19"Release tag for the stable AKS MCP Server tool release.
aks.argoCDEnabledbooleantrueEnable Argo CD GitOps integration commands (Create Argo CD Application, Apply Argo CD Application, Check Argo CD Status, Post-Deploy Actions). Requires reload after changing.
aks.containerAssist.enableGitHubIntegrationbooleantrueEnable Git staging and GitHub PR creation for generated container and K8s files.
aks.containerAssist.k8sManifestFolderstring"k8s"Folder name for generated Kubernetes manifests (relative to project root).
aks.containerAssist.modelFamilystring"gpt-5.2-codex"Default language model family for Container Assist (e.g. gpt-5.2, claude-sonnet).
aks.containerAssist.modelVendorstring"copilot"Default language model vendor for Container Assist (e.g. copilot).
aks.containerAssist.prCreateAsDraftbooleantrueCreate Pull Requests as draft by default.
aks.containerAssist.prDefaultBranchstring"main"Default base branch for Pull Requests created from Container Assist.
aks.containerAssist.promptForPullRequestbooleantruePrompt before creating a Pull Request after staging generated files.
aks.containerAssistEnabledPreviewbooleantrueSet to true to enable deployment related file generation capability using AI tool. (Preview feature)
aks.copilotEnabledPreviewbooleantrueSet to true to enable GH Copilot hook. (Preview feature)
aks.drafttool.releaseTagstring"v0.17.14"Release tag for the stable Draft tool release.
aks.kickstartEnabledPreviewbooleanfalseSet to true to enable the Kickstart agent for AI-guided AKS Automatic deployment onboarding. (Preview feature)
aks.retinatool.releaseTagstring"v1.2.2"Release tag for the stable Retina tool release.
aks.selectedClustersarraySelected Azure Clusters
aks.selectedSubscriptionsarraySelected Azure subscriptions
aks.simplifiedMenuStructurebooleantrueUse the grouped AKS menu (Develop & Deploy, Troubleshoot & Diagnose, Manage Cluster). When disabled, the classic menu layout is shown. Requires reload after changing. You can also toggle this via the commands ‘AKS: Switch to Classic Menu’ and ‘AKS: Switch to Grouped Menu’.
azure.customkubectl.commandsarray[]All the custom kubectl commands
azure.kubectlgadget.releaseTagstring"v0.53.2"Release tag for the stable kubectl-gadget tool.
azure.kubelogin.releaseTagstring"v0.2.19"Release tag for the stable kubelogin tool release. This value is also substituted into generated GitHub Actions workflows for the azure/use-kubelogin action’s kubelogin-version input.